;#> binsrch.dc2
; Identifier     binsrch
;
; Purpose        Do the binary seach of an array to find the index
;                of a given function value(s) 
;
; Synopsis       status = binsrch(xarr , x, index)
;                             
;
; Arguments      Name      I/O       Type           Description
;                -----------------------------------------------------
;                xarr      I    any except string   input array 
;                x         I    any except string   function value(or array)
;                index     O     int array          index (indices array) of 
;                                                   x in xarr
;
; Returns        Error status, 1 for fatal, 0 otherwise   
;
; Description    A binary search is used to find the values XARR(I)
;                and XARR(I+1) where XARR(I) < X < XARR(I+1).
;
; Comment        
;
; Example        stat = binsrch(wave, wref, indx)
;
; Dependencies   CALLS:    sap_error
;                CALLED FROM: inter_pol
;
; Category       ISAP
;
; Filename       binsrch.pro
;
; Author         I. R. Khan       
;
; Version        0.1
;
; History        0.1 25.8.95   Design and Code --> irk
;
; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Copyright (C) 1995, California Institute of Technology.  ;
; U.S. Government Sponsorship under NASA Contract NAS7-918 ;
; is acknowledged.                                         ;
; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;#<

FUNCTION  binsrch, xarr, x, rarr

  status = 0
  np = n_elements(xarr) - 1
  npoints = np + 1

; check for size
  if n_elements(xarr)  le 1 THEN BEGIN
     SAP_ERROR, 'F', ' Search array must contain at least 2 elements'
     return, 1
   ENDIF 

; check for increasing: ascend = 0 means monotonically decreasing
  ascend = xarr(0) LT xarr(np)



; set search end points
     npo = n_elements(x)
     low = intarr(npo) & high = low 
     low = 0 & high = np

; number of divisions needed : np  = 2^steps - 1
     ndiv = FIX (ALOG10(npoints) / ALOG10(2.0) + 1.0)

     FOR i = 1, ndiv  DO BEGIN
       mid = (low + high)/2           ; bisect the interval
       xval = xarr(mid)
       xgt = (x GT xval)      
       xle = (x LE xval)      
       IF ascend THEN BEGIN           ; new low and high for monot. inreasing
	 low = low * xle + mid*xgt  
	 high = high * xgt + mid * xle 
       ENDIF ELSE BEGIN
	 high = high * xle+ mid * xgt   ; new low and high for monot. decreasing
	 low = low * xgt + mid * xle
       ENDELSE
	 
     ENDFOR  
 
   rarr = low

; if x is not an array, return scalar
   if(npo EQ 1) THEN rarr = rarr(0)

   return, 0    
   end

