;#> sap_keyword_set.dc2
; Identifier     sap_keyword_set
;
; Purpose        Check if a keyword is set. The difference to IDLs keyword_set
;                is that a value of zero is allowed and that the string 'NONE'
;                is interpreted as 'not set'.
;
; Synopsis       set=sap_keyword_set(key)
;
; Arguments      Name      I/O  Type      Description
;                -----------------------------------------------------
;                key        I   keyword   the keyword to check
;                
; Returns        0 if keyword is not set or if its value is 'NONE',
;                1 else
;
; Description    To explicitly un-set a keyword use the string 'NONE' as value.
;                Caution: case and blank sensitive!
;
; Comment        ---
;
; Example        if sap_keyword_set(det) then .....
;
; Dependencies   CALLS: --
;                CALLED FROM: general auxillary routine
;
; Category       ISAP
;
; Filename       sap_keyword_set
;
; Author         E. Sturm (--> ES)
;
; Version        1.0
;
; History        0.1   20-10-95  ES    
;                1.0   30-11-95  ES  V1 delivery
; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Copyright (C) 1995, Max-Planck-Institut fuer extraterrestrische Physik (MPE);
;                     Garching, Germany                                       ;
; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;#<

 FUNCTION sap_keyword_set,key

 s=size(key)
 ns=n_elements(s)
 if total(s) eq 1 then begin      ;keyword not set or value undefined
   set=0
 endif else begin
   set=1
   if s(ns-2) eq 7 then begin     ;value is a string
;;      if strtrim(strlowcase(key),2) eq 'none' then a = 0
      if key(0) eq 'NONE' then set = 0
   endif
 endelse

 return, set

 END
